@@ -37,6 +37,7 @@ def run(
     },
     z_score_x: bool = True,
     z_score_theta: bool = True,
+    max_num_epochs: Optional[int] = None,
 ) -> Tuple[torch.Tensor, int, Optional[torch.Tensor]]:
     """Runs (S)NLE from `sbi`
 
@@ -56,6 +57,7 @@ def run(
         mcmc_parameters: MCMC parameters
         z_score_x: Whether to z-score x
         z_score_theta: Whether to z-score theta
+        max_num_epochs: Maximum number of epochs
 
     Returns:
         Samples from posterior, number of simulator calls, log probability of true params if computable
@@ -105,6 +107,7 @@ def run(
     posteriors = []
     proposal = prior
     mcmc_parameters["warmup_steps"] = 25
+    mcmc_parameters["enable_transform"] = False  # NOTE: Disable `sbi` auto-transforms, since `sbibm` does its own
 
     for r in range(num_rounds):
         theta, x = inference.simulate_for_sbi(
@@ -121,6 +124,7 @@ def run(
             retrain_from_scratch_each_round=False,
             discard_prior_samples=False,
             show_train_summary=True,
+            max_num_epochs=max_num_epochs,
         )
         if r > 1:
             mcmc_parameters["init_strategy"] = "latest_sample"
